Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppModel ¶
type AppModel struct {
// contains filtered or unexported fields
}
AppModel is the parent model that manages switching between views
func NewAppModel ¶
NewAppModel creates a new app model
type CustomDelegate ¶
type CustomDelegate struct {
list.DefaultDelegate
// contains filtered or unexported fields
}
CustomDelegate extends the default delegate with custom rendering
type Item ¶
type Item struct {
// contains filtered or unexported fields
}
Item represents a video in the list
func (Item) Description ¶
Description returns the item description
func (Item) FilterValue ¶
FilterValue returns the value to filter on
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model represents the UI state
func (Model) ReturnFromSubscriptions ¶
func (m Model) ReturnFromSubscriptions() tea.Cmd
Add a new method to handle returning from subscription manager
type SubscriptionItem ¶
SubscriptionItem represents a channel subscription
func (SubscriptionItem) Description ¶
func (i SubscriptionItem) Description() string
Description returns the item description
func (SubscriptionItem) FilterValue ¶
func (i SubscriptionItem) FilterValue() string
FilterValue implements list.Item interface
func (SubscriptionItem) Title ¶
func (i SubscriptionItem) Title() string
Title returns the item title
type SubscriptionModel ¶
type SubscriptionModel struct {
// contains filtered or unexported fields
}
SubscriptionModel represents the subscription manager UI state
func NewSubscriptionModel ¶
func NewSubscriptionModel(client *youtube.Client) SubscriptionModel
NewSubscriptionModel creates a new subscription manager model
func (SubscriptionModel) Init ¶
func (m SubscriptionModel) Init() tea.Cmd
Init initializes the subscription manager model
func (SubscriptionModel) Update ¶
func (m SubscriptionModel) Update(msg tea.Msg) (tea.Model, tea.Cmd)
Update handles UI updates for the subscription manager
func (SubscriptionModel) View ¶
func (m SubscriptionModel) View() string
View renders the subscription manager UI